@@ -18,7 +18,7 @@ def set_attr_from_dict(obj, attr_name, mapping, key, ignore_errors=False):
     If no such *key* is in the dict, nothing is done.
     Any TypeErrors or ValueErrors are silently ignored, if *ignore_errors is set.
 
-    Returns true is *key* was present in *map* and the attribute was successfully set. Otherwise False is returned.
+    Returns true is *key* was present in *map* and the attribute was successfully set. Otherwise, False is returned.
     """
     try:
         value = mapping.pop(key)
@@ -43,7 +43,7 @@ def set_enum_attr_from_dict(obj, attr_name, enum_type, mapping, key, ignore_erro
     If no such *key* is in the dict nothing is done.
     Any TypeErrors or ValueErrors are silently ignored, if *ignore_errors is set.
 
-    Returns true is *key* was present in *map* and the attribute was successfully set. Otherwise False is returned.
+    Returns true is *key* was present in *map* and the attribute was successfully set. Otherwise, False is returned.
     """
     try:
         value = mapping.pop(key)
@@ -73,11 +73,15 @@ STAGE_AXES = frozenset(('x', 'y', 'z', 'a', 'b'))
 
 class BaseMicroscope(ABC):
     """
-    Base class for Microscope classes. Do not use directly.
+    Abstract base class for microscope classes.
+
+    Do not use `BaseMicroscope` directly, instead instantiate
+    one of the subclasses, like :class:`Microscope` or :class:`RemoteMicroscope`. The Subclasses
+    implement all the abstract methods.
     """
     @abstractmethod
     def get_family(self):
-        """Return product family (see :class:`ProductFamily`): "TITAN", "TECNAI", ..."""
+        """Return product family (see :class:`ProductFamily` for values): "TITAN", "TECNAI", ..."""
         raise NotImplementedError
 
     @abstractmethod
@@ -124,6 +128,29 @@ class BaseMicroscope(ABC):
         """
         raise NotImplementedError
 
+    @abstractmethod
+    def get_column_valves_open(self):
+        """
+        Returns state of the column valves.
+
+        :return: `True`, if column valves are open. `False`, otherwise.
+
+        .. versionadded: 2.1.0
+        """
+        raise NotImplementedError
+
+    @abstractmethod
+    def set_column_valves_open(self, state):
+        """
+        Set state of the column valves. The column valves are opened, if `True` is passes as *state*
+
+        :param state: `True`, if column valves should be opened. `False`, if they should be closed.
+        :type state: bool
+
+        .. versionadded: 2.0.1
+        """
+        raise NotImplementedError
+
     @abstractmethod
     def get_stage_holder(self):
         """Return holder currently in stage (see :class:`StageHolderType`)"""
